.. highlight:: python

===========
ModalWindow
===========

.. module:: vanilla
.. autoclass:: ModalWindow
   :inherited-members:
   :members:


.. module:: vanilla
.. autoclass:: vanilla.vanillaWindows.VModalWindow
   :inherited-members:
   :members:

